netapp_ontap.resources.network_route API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.network_route`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This endpoint supports the following operations: GET (collection and instance), POST, and DELETE.

## Retrieving network routes

You can use the IP routes GET API to retrieve and display relevant information pertaining to the routes configured in the cluster. The API retrieves the list of all routes configured in the cluster, or a specific route. The fields that are returned in the response will differ with the configuration.

## Examples

### Retrieving all routes in the cluster

The following output shows the list of all routes configured in a cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(NetworkRoute.get_collection(fields="*")))

Try it out

    [
        NetworkRoute(
            {
                "ipspace": {
                    "uuid": "84f4beb2-616c-11e8-a4df-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/network/ipspaces/84f4beb2-616c-11e8-a4df-005056b4c971"
                        }
                    },
                    "name": "Default",
                },
                "uuid": "5fdffb0b-62f8-11e8-853d-005056b4c971",
                "scope": "svm",
                "gateway": "10.4.3.1",
                "_links": {
                    "self": {
                        "href": "/api/network/ip/routes/5fdffb0b-62f8-11e8-853d-005056b4c971"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "uuid": "3243312c-62f8-11e8-853d-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/3243312c-62f8-11e8-853d-005056b4c971"
                        }
                    },
                },
                "destination": {"netmask": "18", "address": "10.4.3.14", "family": "ipv4"},
            }
        ),
        NetworkRoute(
            {
                "ipspace": {
                    "uuid": "cc71aadc-62f7-11e8-853d-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/network/ipspaces/cc71aadc-62f7-11e8-853d-005056b4c971"
                        }
                    },
                    "name": "ips1",
                },
                "uuid": "84c128d2-62f9-11e8-853d-005056b4c971",
                "scope": "cluster",
                "gateway": "fd20:8b1e:b255:814e::1",
                "_links": {
                    "self": {
                        "href": "/api/network/ip/routes/84c128d2-62f9-11e8-853d-005056b4c971"
                    }
                },
                "destination": {"netmask": "0", "address": "::", "family": "ipv6"},
            }
        ),
        NetworkRoute(
            {
                "ipspace": {
                    "uuid": "84f4beb2-616c-11e8-a4df-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/network/ipspaces/84f4beb2-616c-11e8-a4df-005056b4c971"
                        }
                    },
                    "name": "Default",
                },
                "uuid": "8cc72bcd-616c-11e8-a4df-005056b4c971",
                "scope": "cluster",
                "gateway": "10.224.64.1",
                "_links": {
                    "self": {
                        "href": "/api/network/ip/routes/8cc72bcd-616c-11e8-a4df-005056b4c971"
                    }
                },
                "destination": {"netmask": "0", "address": "0.0.0.0", "family": "ipv4"},
            }
        ),
        NetworkRoute(
            {
                "ipspace": {
                    "uuid": "84f4beb2-616c-11e8-a4df-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/network/ipspaces/84f4beb2-616c-11e8-a4df-005056b4c971"
                        }
                    },
                    "name": "Default",
                },
                "uuid": "d63b6eee-62f9-11e8-853d-005056b4c971",
                "scope": "svm",
                "gateway": "fd20:8b1e:b255:814e::1",
                "_links": {
                    "self": {
                        "href": "/api/network/ip/routes/d63b6eee-62f9-11e8-853d-005056b4c971"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "uuid": "3243312c-62f8-11e8-853d-005056b4c971",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/3243312c-62f8-11e8-853d-005056b4c971"
                        }
                    },
                },
                "destination": {
                    "netmask": "64",
                    "address": "fd20:8b1e:b255:814e::",
                    "family": "ipv6",
                },
            }
        ),
    ]

### Retrieving a specific Cluster-scoped route

The following output shows the returned response when a specific Cluster-scoped route is requested. The system returns an error if there is no route with the requested UUID. SVM information is not returned for Cluster-scoped routes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NetworkRoute(uuid="84c128d2-62f9-11e8-853d-005056b4c971")
        resource.get(fields="*")
        print(resource)

Try it out

    NetworkRoute(
        {
            "ipspace": {
                "uuid": "cc71aadc-62f7-11e8-853d-005056b4c971",
                "_links": {
                    "self": {
                        "href": "/api/network/ipspaces/cc71aadc-62f7-11e8-853d-005056b4c971"
                    }
                },
                "name": "ips1",
            },
            "uuid": "84c128d2-62f9-11e8-853d-005056b4c971",
            "scope": "cluster",
            "gateway": "fd20:8b1e:b255:814e::1",
            "_links": {
                "self": {
                    "href": "/api/network/ip/routes/84c128d2-62f9-11e8-853d-005056b4c971"
                }
            },
            "destination": {"netmask": "0", "address": "::", "family": "ipv6"},
        }
    )

### Retrieving a specific SVM-scoped route

The following output shows the returned response when a specific SVM-scoped route is requested. The system returns an error if there is no route with the requested UUID. The SVM object is only included for SVM-scoped routes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NetworkRoute(uuid="d63b6eee-62f9-11e8-853d-005056b4c971")
        resource.get(fields="*")
        print(resource)

Try it out

    NetworkRoute(
        {
            "ipspace": {
                "uuid": "84f4beb2-616c-11e8-a4df-005056b4c971",
                "_links": {
                    "self": {
                        "href": "/api/network/ipspaces/84f4beb2-616c-11e8-a4df-005056b4c971"
                    }
                },
                "name": "Default",
            },
            "uuid": "d63b6eee-62f9-11e8-853d-005056b4c971",
            "scope": "svm",
            "gateway": "fd20:8b1e:b255:814e::1",
            "_links": {
                "self": {
                    "href": "/api/network/ip/routes/d63b6eee-62f9-11e8-853d-005056b4c971"
                }
            },
            "svm": {
                "name": "vs1",
                "uuid": "3243312c-62f8-11e8-853d-005056b4c971",
                "_links": {
                    "self": {"href": "/api/svm/svms/3243312c-62f8-11e8-853d-005056b4c971"}
                },
            },
            "destination": {
                "netmask": "64",
                "address": "fd20:8b1e:b255:814e::",
                "family": "ipv6",
            },
        }
    )

## Creating network routes

You can use the POST API to create an SVM-scoped route by specifying the associated SVM, or a Cluster-scoped route by specifying the associated IPspace.

## Examples

### Creating a Cluster-scoped route

IPspace is required to create a Cluster-scoped route. If the IPspace is not specified, the route will be created in the Default IPspace. The default destination will be set to "0.0.0.0/0" for IPv4 gateway addresses or "::/0" for IPv6 gateway addresses.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NetworkRoute()
        resource.ipspace.name = "ips1"
        resource.gateway = "10.10.10.1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    NetworkRoute(
        {
            "ipspace": {"name": "ips1"},
            "uuid": "ae583c9e-9ac7-11e8-8bc9-005056bbd531",
            "gateway": "10.10.10.1",
        }
    )

### Creating an SVM-scoped route

To create an SVM-scoped route, the associated SVM can be identified by either its UUID or name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NetworkRoute()
        resource.svm.name = "vs0"
        resource.gateway = "10.10.10.1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    NetworkRoute(
        {
            "uuid": "38805a91-9ac9-11e8-8bc9-005056bbd531",
            "gateway": "10.10.10.1",
            "svm": {"name": "vs0"},
        }
    )

## Deleting network routes

You can use the DELETE API to delete a specific route identified by its UUID.

## Example

### Deleting a specific route

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NetworkRoute

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NetworkRoute(uuid="38805a91-9ac9-11e8-8bc9-005056bbd531")
        resource.delete()

## Classes

`class NetworkRoute (*args, **kwargs)`

  Allows interaction with NetworkRoute objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the collection of IP routes.

    ### Related ONTAP commands

    - `network route show`

    ### Learn more

    - `DOC /network/ip/routes`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a specific IP route.

    ### Related ONTAP commands

    - `network route delete`

    ### Learn more

    - `DOC /network/ip/routes`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the collection of IP routes.

    ### Related ONTAP commands

    - `network route show`

    ### Learn more

    - `DOC /network/ip/routes`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the collection of IP routes.

    ### Related ONTAP commands

    - `network route show`

    ### Learn more

    - `DOC /network/ip/routes`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a specific IP route.

    ### Related ONTAP commands

    - `network route delete`

    ### Learn more

    - `DOC /network/ip/routes`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the details of a specific IP route.

    ### Related ONTAP commands

    - `network route show`

    ### Learn more

    - `DOC /network/ip/routes`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a Cluster-scoped or SVM-scoped static route.

    ### Required properties

    - `gateway` - IP address to route packets to.
    - SVM-scoped routes
    - `svm.name` or `svm.uuid` - SVM that route is applied to.
    - cluster-scoped routes
    - There are no additional required fields for Cluster-scoped routes.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `destination` - 0.0.0.0/0 for IPv4 or ::/0 for IPv6. * `ipspace.name` * Default for Cluster-scoped routes. * Name of the SVM's IPspace for SVM-scoped routes.

    ### Related ONTAP commands

    - `network route create`

    ### Learn more

    - `DOC /network/ip/routes`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class NetworkRouteSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NetworkRoute object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `destination GET POST PATCH`

    The destination field of the network_route.

  `gateway GET POST PATCH`

    The IP address of the gateway router leading to the destination.

    Example: 10.1.1.1

  `ipspace GET POST PATCH`

    The ipspace field of the network_route.

  `links GET`

    The links field of the network_route.

  `scope GET POST PATCH`

    The scope field of the network_route.

  `svm GET POST PATCH`

    The svm field of the network_route.

  `uuid GET`

    The UUID that uniquely identifies the route.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412